==> p4dti-kit-1.1.6.tar.gz: p4dti-kit-1.1.6/code/replicator/teamtrack.py <==
#             Perforce Defect Tracking Integration Project
#              <http://www.ravenbrook.com/project/p4dti/>
#
#            TEAMTRACK.PY -- PYTHON INTERFACE TO TEAMTRACK
#
#             Gareth Rees, Ravenbrook Limited, 2001-07-03
#
#
# 1. INTRODUCTION
#
# This document implements a Python interface to TeamTrack [GDR
# 2000-08-08].  The interface is portable between TeamTrack 4.5 and
# TeamTrack 5.0: it loads the appropriate Python extension
# (teamtrack45.pyd or teamtrack50.pyd respectively) based on the
# teamtrack_version configuration parameter.

import catalog
import config

error = "TeamTrack interface error"

if config.teamtrack_version == '4.5':
    from teamtrack45 import *
elif config.teamtrack_version == '5.0':
    from teamtrack50 import *
else:
    # "TeamTrack version %s is not supported by the P4DTI."
    raise error, catalog.msg(1003, config.teamtrack_version)


# A. REFERENCES
#
# [GDR 2000-08-08] "Python interface to TeamTrack: design"; Gareth Rees;
# Ravenbrook Limited; 2000-08-08.
#
#
# B. DOCUMENT HISTORY
#
# 2001-07-03 GDR Created.
#
#
# C. COPYRIGHT AND LICENCE
#
# This file is copyright (c) 2001 Perforce Software, Inc.  All
# rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1.  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in
#     the documentation and/or other materials provided with the
#     distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDERS AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#
#
# $Id: //info.ravenbrook.com/project/p4dti/version/1.1/code/replicator/teamtrack.py#1 $

==> p4dti-kit-1.5.3.tar.gz: p4dti-kit-1.5.3/code/replicator/teamtrack.py <==
#             Perforce Defect Tracking Integration Project
#              <http://www.ravenbrook.com/project/p4dti/>
#
#            TEAMTRACK.PY -- PYTHON INTERFACE TO TEAMTRACK
#
#             Gareth Rees, Ravenbrook Limited, 2001-07-03
#
#
# 1. INTRODUCTION
#
# This document implements a Python interface to TeamTrack [GDR
# 2000-08-08].  The interface is portable between TeamTrack 4.5 and
# TeamTrack 5.0: it loads the appropriate Python extension
# (teamtrack45.pyd or teamtrack50.pyd respectively) based on the
# teamtrack_version configuration parameter.

import catalog
from config_loader import config

error = "TeamTrack interface error"

if config.teamtrack_version == '4.5':
    from teamtrack45 import *
elif config.teamtrack_version >= '5.0':
    from teamtrack50 import *
else:
    # "TeamTrack version %s is not supported by the P4DTI."
    raise error, catalog.msg(1003, config.teamtrack_version)


# A. REFERENCES
#
# [GDR 2000-08-08] "Python interface to TeamTrack: design"; Gareth Rees;
# Ravenbrook Limited; 2000-08-08;
# <http://www.ravenbrook.com/project/p4dti/version/1.5/design/python-teamtrack-interface/>.
#
#
# B. DOCUMENT HISTORY
#
# 2001-07-03 GDR Created.
#
#
# C. COPYRIGHT AND LICENCE
#
# This file is copyright (c) 2001 Perforce Software, Inc.  All
# rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# 1.  Redistributions of source code must retain the above copyright
#     notice, this list of conditions and the following disclaimer.
#
# 2.  Redistributions in binary form must reproduce the above copyright
#     notice, this list of conditions and the following disclaimer in
#     the documentation and/or other materials provided with the
#     distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDERS AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
# OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
# TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
# USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#
#
# $Id: //info.ravenbrook.com/project/p4dti/version/1.5/code/replicator/teamtrack.py#3 $
